# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ScalewayCredentialsArgs', 'ScalewayCredentials']

@pulumi.input_type
class ScalewayCredentialsArgs:
    def __init__(__self__, *,
                 organization_id: pulumi.Input[str],
                 scaleway_access_key: pulumi.Input[str],
                 scaleway_organization_id: pulumi.Input[str],
                 scaleway_project_id: pulumi.Input[str],
                 scaleway_secret_key: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ScalewayCredentials resource.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] scaleway_access_key: Your SCALEWAY access key id.
        :param pulumi.Input[str] scaleway_organization_id: Your SCALEWAY organization ID.
        :param pulumi.Input[str] scaleway_project_id: Your SCALEWAY project ID.
        :param pulumi.Input[str] scaleway_secret_key: Your SCALEWAY secret key.
        :param pulumi.Input[str] name: Name of the scaleway credentials.
        """
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "scaleway_access_key", scaleway_access_key)
        pulumi.set(__self__, "scaleway_organization_id", scaleway_organization_id)
        pulumi.set(__self__, "scaleway_project_id", scaleway_project_id)
        pulumi.set(__self__, "scaleway_secret_key", scaleway_secret_key)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Input[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="scalewayAccessKey")
    def scaleway_access_key(self) -> pulumi.Input[str]:
        """
        Your SCALEWAY access key id.
        """
        return pulumi.get(self, "scaleway_access_key")

    @scaleway_access_key.setter
    def scaleway_access_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "scaleway_access_key", value)

    @property
    @pulumi.getter(name="scalewayOrganizationId")
    def scaleway_organization_id(self) -> pulumi.Input[str]:
        """
        Your SCALEWAY organization ID.
        """
        return pulumi.get(self, "scaleway_organization_id")

    @scaleway_organization_id.setter
    def scaleway_organization_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "scaleway_organization_id", value)

    @property
    @pulumi.getter(name="scalewayProjectId")
    def scaleway_project_id(self) -> pulumi.Input[str]:
        """
        Your SCALEWAY project ID.
        """
        return pulumi.get(self, "scaleway_project_id")

    @scaleway_project_id.setter
    def scaleway_project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "scaleway_project_id", value)

    @property
    @pulumi.getter(name="scalewaySecretKey")
    def scaleway_secret_key(self) -> pulumi.Input[str]:
        """
        Your SCALEWAY secret key.
        """
        return pulumi.get(self, "scaleway_secret_key")

    @scaleway_secret_key.setter
    def scaleway_secret_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "scaleway_secret_key", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the scaleway credentials.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ScalewayCredentialsState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 scaleway_access_key: Optional[pulumi.Input[str]] = None,
                 scaleway_organization_id: Optional[pulumi.Input[str]] = None,
                 scaleway_project_id: Optional[pulumi.Input[str]] = None,
                 scaleway_secret_key: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ScalewayCredentials resources.
        :param pulumi.Input[str] name: Name of the scaleway credentials.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] scaleway_access_key: Your SCALEWAY access key id.
        :param pulumi.Input[str] scaleway_organization_id: Your SCALEWAY organization ID.
        :param pulumi.Input[str] scaleway_project_id: Your SCALEWAY project ID.
        :param pulumi.Input[str] scaleway_secret_key: Your SCALEWAY secret key.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if scaleway_access_key is not None:
            pulumi.set(__self__, "scaleway_access_key", scaleway_access_key)
        if scaleway_organization_id is not None:
            pulumi.set(__self__, "scaleway_organization_id", scaleway_organization_id)
        if scaleway_project_id is not None:
            pulumi.set(__self__, "scaleway_project_id", scaleway_project_id)
        if scaleway_secret_key is not None:
            pulumi.set(__self__, "scaleway_secret_key", scaleway_secret_key)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the scaleway credentials.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="scalewayAccessKey")
    def scaleway_access_key(self) -> Optional[pulumi.Input[str]]:
        """
        Your SCALEWAY access key id.
        """
        return pulumi.get(self, "scaleway_access_key")

    @scaleway_access_key.setter
    def scaleway_access_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scaleway_access_key", value)

    @property
    @pulumi.getter(name="scalewayOrganizationId")
    def scaleway_organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        Your SCALEWAY organization ID.
        """
        return pulumi.get(self, "scaleway_organization_id")

    @scaleway_organization_id.setter
    def scaleway_organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scaleway_organization_id", value)

    @property
    @pulumi.getter(name="scalewayProjectId")
    def scaleway_project_id(self) -> Optional[pulumi.Input[str]]:
        """
        Your SCALEWAY project ID.
        """
        return pulumi.get(self, "scaleway_project_id")

    @scaleway_project_id.setter
    def scaleway_project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scaleway_project_id", value)

    @property
    @pulumi.getter(name="scalewaySecretKey")
    def scaleway_secret_key(self) -> Optional[pulumi.Input[str]]:
        """
        Your SCALEWAY secret key.
        """
        return pulumi.get(self, "scaleway_secret_key")

    @scaleway_secret_key.setter
    def scaleway_secret_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "scaleway_secret_key", value)


class ScalewayCredentials(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 scaleway_access_key: Optional[pulumi.Input[str]] = None,
                 scaleway_organization_id: Optional[pulumi.Input[str]] = None,
                 scaleway_project_id: Optional[pulumi.Input[str]] = None,
                 scaleway_secret_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## # ScalewayCredentials (Resource)

        Provides a Qovery SCALEWAY credentials resource. This can be used to create and manage Qovery SCALEWAY credentials.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_scaleway_creds = qovery.ScalewayCredentials("myScalewayCreds",
            organization_id=qovery_organization["my_organization"]["id"],
            scaleway_access_key="<your-scaleway-access-key>",
            scaleway_secret_key="<your-scaleway-secret-key>",
            scaleway_project_id="<your-scaleway-project-id>",
            opts=pulumi.ResourceOptions(depends_on=[qovery_organization["my_organization"]]))
        ```

        ## Import

        ```sh
         $ pulumi import qovery:index/scalewayCredentials:ScalewayCredentials my_scaleway_creds "<organization_id>,<scaleway_credentials_id>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Name of the scaleway credentials.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] scaleway_access_key: Your SCALEWAY access key id.
        :param pulumi.Input[str] scaleway_organization_id: Your SCALEWAY organization ID.
        :param pulumi.Input[str] scaleway_project_id: Your SCALEWAY project ID.
        :param pulumi.Input[str] scaleway_secret_key: Your SCALEWAY secret key.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ScalewayCredentialsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # ScalewayCredentials (Resource)

        Provides a Qovery SCALEWAY credentials resource. This can be used to create and manage Qovery SCALEWAY credentials.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_scaleway_creds = qovery.ScalewayCredentials("myScalewayCreds",
            organization_id=qovery_organization["my_organization"]["id"],
            scaleway_access_key="<your-scaleway-access-key>",
            scaleway_secret_key="<your-scaleway-secret-key>",
            scaleway_project_id="<your-scaleway-project-id>",
            opts=pulumi.ResourceOptions(depends_on=[qovery_organization["my_organization"]]))
        ```

        ## Import

        ```sh
         $ pulumi import qovery:index/scalewayCredentials:ScalewayCredentials my_scaleway_creds "<organization_id>,<scaleway_credentials_id>"
        ```

        :param str resource_name: The name of the resource.
        :param ScalewayCredentialsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ScalewayCredentialsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 scaleway_access_key: Optional[pulumi.Input[str]] = None,
                 scaleway_organization_id: Optional[pulumi.Input[str]] = None,
                 scaleway_project_id: Optional[pulumi.Input[str]] = None,
                 scaleway_secret_key: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ScalewayCredentialsArgs.__new__(ScalewayCredentialsArgs)

            __props__.__dict__["name"] = name
            if organization_id is None and not opts.urn:
                raise TypeError("Missing required property 'organization_id'")
            __props__.__dict__["organization_id"] = organization_id
            if scaleway_access_key is None and not opts.urn:
                raise TypeError("Missing required property 'scaleway_access_key'")
            __props__.__dict__["scaleway_access_key"] = scaleway_access_key
            if scaleway_organization_id is None and not opts.urn:
                raise TypeError("Missing required property 'scaleway_organization_id'")
            __props__.__dict__["scaleway_organization_id"] = scaleway_organization_id
            if scaleway_project_id is None and not opts.urn:
                raise TypeError("Missing required property 'scaleway_project_id'")
            __props__.__dict__["scaleway_project_id"] = scaleway_project_id
            if scaleway_secret_key is None and not opts.urn:
                raise TypeError("Missing required property 'scaleway_secret_key'")
            __props__.__dict__["scaleway_secret_key"] = None if scaleway_secret_key is None else pulumi.Output.secret(scaleway_secret_key)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["scalewaySecretKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ScalewayCredentials, __self__).__init__(
            'qovery:index/scalewayCredentials:ScalewayCredentials',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            scaleway_access_key: Optional[pulumi.Input[str]] = None,
            scaleway_organization_id: Optional[pulumi.Input[str]] = None,
            scaleway_project_id: Optional[pulumi.Input[str]] = None,
            scaleway_secret_key: Optional[pulumi.Input[str]] = None) -> 'ScalewayCredentials':
        """
        Get an existing ScalewayCredentials resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Name of the scaleway credentials.
        :param pulumi.Input[str] organization_id: Id of the organization.
        :param pulumi.Input[str] scaleway_access_key: Your SCALEWAY access key id.
        :param pulumi.Input[str] scaleway_organization_id: Your SCALEWAY organization ID.
        :param pulumi.Input[str] scaleway_project_id: Your SCALEWAY project ID.
        :param pulumi.Input[str] scaleway_secret_key: Your SCALEWAY secret key.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ScalewayCredentialsState.__new__(_ScalewayCredentialsState)

        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["scaleway_access_key"] = scaleway_access_key
        __props__.__dict__["scaleway_organization_id"] = scaleway_organization_id
        __props__.__dict__["scaleway_project_id"] = scaleway_project_id
        __props__.__dict__["scaleway_secret_key"] = scaleway_secret_key
        return ScalewayCredentials(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the scaleway credentials.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        Id of the organization.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="scalewayAccessKey")
    def scaleway_access_key(self) -> pulumi.Output[str]:
        """
        Your SCALEWAY access key id.
        """
        return pulumi.get(self, "scaleway_access_key")

    @property
    @pulumi.getter(name="scalewayOrganizationId")
    def scaleway_organization_id(self) -> pulumi.Output[str]:
        """
        Your SCALEWAY organization ID.
        """
        return pulumi.get(self, "scaleway_organization_id")

    @property
    @pulumi.getter(name="scalewayProjectId")
    def scaleway_project_id(self) -> pulumi.Output[str]:
        """
        Your SCALEWAY project ID.
        """
        return pulumi.get(self, "scaleway_project_id")

    @property
    @pulumi.getter(name="scalewaySecretKey")
    def scaleway_secret_key(self) -> pulumi.Output[str]:
        """
        Your SCALEWAY secret key.
        """
        return pulumi.get(self, "scaleway_secret_key")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['DeploymentArgs', 'Deployment']

@pulumi.input_type
class DeploymentArgs:
    def __init__(__self__, *,
                 desired_state: pulumi.Input[str],
                 environment_id: pulumi.Input[str],
                 version: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Deployment resource.
        :param pulumi.Input[str] desired_state: Desired state of the deployment. - Can be: `RESTARTED`, `RUNNING`, `STOPPED`.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[str] version: Version to force trigger a deployment when desired_state doesn't change (e.g redeploy a deployment having the 'RUNNING'
               state)
        """
        pulumi.set(__self__, "desired_state", desired_state)
        pulumi.set(__self__, "environment_id", environment_id)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="desiredState")
    def desired_state(self) -> pulumi.Input[str]:
        """
        Desired state of the deployment. - Can be: `RESTARTED`, `RUNNING`, `STOPPED`.
        """
        return pulumi.get(self, "desired_state")

    @desired_state.setter
    def desired_state(self, value: pulumi.Input[str]):
        pulumi.set(self, "desired_state", value)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Input[str]:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        Version to force trigger a deployment when desired_state doesn't change (e.g redeploy a deployment having the 'RUNNING'
        state)
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class _DeploymentState:
    def __init__(__self__, *,
                 desired_state: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Deployment resources.
        :param pulumi.Input[str] desired_state: Desired state of the deployment. - Can be: `RESTARTED`, `RUNNING`, `STOPPED`.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[str] version: Version to force trigger a deployment when desired_state doesn't change (e.g redeploy a deployment having the 'RUNNING'
               state)
        """
        if desired_state is not None:
            pulumi.set(__self__, "desired_state", desired_state)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="desiredState")
    def desired_state(self) -> Optional[pulumi.Input[str]]:
        """
        Desired state of the deployment. - Can be: `RESTARTED`, `RUNNING`, `STOPPED`.
        """
        return pulumi.get(self, "desired_state")

    @desired_state.setter
    def desired_state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "desired_state", value)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        Version to force trigger a deployment when desired_state doesn't change (e.g redeploy a deployment having the 'RUNNING'
        state)
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)


class Deployment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 desired_state: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## # Deployment (Resource)

        Provides a Qovery deployment resource. This is used to trigger a service deployment at demand.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_deployment = qovery.Deployment("myDeployment",
            environment_id=qovery_environment["my_environment"]["id"],
            desired_state="RUNNING",
            version="random_uuid_to_force_retrigger_terraform_apply",
            opts=pulumi.ResourceOptions(depends_on=[
                    qovery_application["my_application"],
                    qovery_database["my_database"],
                    qovery_container["my_container"],
                ]))
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] desired_state: Desired state of the deployment. - Can be: `RESTARTED`, `RUNNING`, `STOPPED`.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[str] version: Version to force trigger a deployment when desired_state doesn't change (e.g redeploy a deployment having the 'RUNNING'
               state)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeploymentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # Deployment (Resource)

        Provides a Qovery deployment resource. This is used to trigger a service deployment at demand.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_deployment = qovery.Deployment("myDeployment",
            environment_id=qovery_environment["my_environment"]["id"],
            desired_state="RUNNING",
            version="random_uuid_to_force_retrigger_terraform_apply",
            opts=pulumi.ResourceOptions(depends_on=[
                    qovery_application["my_application"],
                    qovery_database["my_database"],
                    qovery_container["my_container"],
                ]))
        ```

        :param str resource_name: The name of the resource.
        :param DeploymentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeploymentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 desired_state: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeploymentArgs.__new__(DeploymentArgs)

            if desired_state is None and not opts.urn:
                raise TypeError("Missing required property 'desired_state'")
            __props__.__dict__["desired_state"] = desired_state
            if environment_id is None and not opts.urn:
                raise TypeError("Missing required property 'environment_id'")
            __props__.__dict__["environment_id"] = environment_id
            __props__.__dict__["version"] = version
        super(Deployment, __self__).__init__(
            'qovery:index/deployment:Deployment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            desired_state: Optional[pulumi.Input[str]] = None,
            environment_id: Optional[pulumi.Input[str]] = None,
            version: Optional[pulumi.Input[str]] = None) -> 'Deployment':
        """
        Get an existing Deployment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] desired_state: Desired state of the deployment. - Can be: `RESTARTED`, `RUNNING`, `STOPPED`.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[str] version: Version to force trigger a deployment when desired_state doesn't change (e.g redeploy a deployment having the 'RUNNING'
               state)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeploymentState.__new__(_DeploymentState)

        __props__.__dict__["desired_state"] = desired_state
        __props__.__dict__["environment_id"] = environment_id
        __props__.__dict__["version"] = version
        return Deployment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="desiredState")
    def desired_state(self) -> pulumi.Output[str]:
        """
        Desired state of the deployment. - Can be: `RESTARTED`, `RUNNING`, `STOPPED`.
        """
        return pulumi.get(self, "desired_state")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Output[str]:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter
    def version(self) -> pulumi.Output[Optional[str]]:
        """
        Version to force trigger a deployment when desired_state doesn't change (e.g redeploy a deployment having the 'RUNNING'
        state)
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetScalewayCredentialsResult',
    'AwaitableGetScalewayCredentialsResult',
    'get_scaleway_credentials',
    'get_scaleway_credentials_output',
]

@pulumi.output_type
class GetScalewayCredentialsResult:
    """
    A collection of values returned by getScalewayCredentials.
    """
    def __init__(__self__, id=None, name=None, organization_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        return pulumi.get(self, "organization_id")


class AwaitableGetScalewayCredentialsResult(GetScalewayCredentialsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetScalewayCredentialsResult(
            id=self.id,
            name=self.name,
            organization_id=self.organization_id)


def get_scaleway_credentials(id: Optional[str] = None,
                             organization_id: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetScalewayCredentialsResult:
    """
    ## # ScalewayCredentials (Data Source)

    Use this data source to retrieve information about an existing Scaleway credentials.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['organizationId'] = organization_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('qovery:index/getScalewayCredentials:getScalewayCredentials', __args__, opts=opts, typ=GetScalewayCredentialsResult).value

    return AwaitableGetScalewayCredentialsResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        organization_id=pulumi.get(__ret__, 'organization_id'))


@_utilities.lift_output_func(get_scaleway_credentials)
def get_scaleway_credentials_output(id: Optional[pulumi.Input[str]] = None,
                                    organization_id: Optional[pulumi.Input[str]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetScalewayCredentialsResult]:
    """
    ## # ScalewayCredentials (Data Source)

    Use this data source to retrieve information about an existing Scaleway credentials.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['DeploymentStageArgs', 'DeploymentStage']

@pulumi.input_type
class DeploymentStageArgs:
    def __init__(__self__, *,
                 environment_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 is_after: Optional[pulumi.Input[str]] = None,
                 is_before: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DeploymentStage resource.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[str] description: Description of the deployment stage.
        :param pulumi.Input[str] is_after: Move the current deployment stage after the target deployment stage
        :param pulumi.Input[str] is_before: Move the current deployment stage before the target deployment stage
        :param pulumi.Input[str] name: Name of the deployment stage.
        """
        pulumi.set(__self__, "environment_id", environment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_after is not None:
            pulumi.set(__self__, "is_after", is_after)
        if is_before is not None:
            pulumi.set(__self__, "is_before", is_before)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Input[str]:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the deployment stage.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="isAfter")
    def is_after(self) -> Optional[pulumi.Input[str]]:
        """
        Move the current deployment stage after the target deployment stage
        """
        return pulumi.get(self, "is_after")

    @is_after.setter
    def is_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "is_after", value)

    @property
    @pulumi.getter(name="isBefore")
    def is_before(self) -> Optional[pulumi.Input[str]]:
        """
        Move the current deployment stage before the target deployment stage
        """
        return pulumi.get(self, "is_before")

    @is_before.setter
    def is_before(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "is_before", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the deployment stage.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _DeploymentStageState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 is_after: Optional[pulumi.Input[str]] = None,
                 is_before: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DeploymentStage resources.
        :param pulumi.Input[str] description: Description of the deployment stage.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[str] is_after: Move the current deployment stage after the target deployment stage
        :param pulumi.Input[str] is_before: Move the current deployment stage before the target deployment stage
        :param pulumi.Input[str] name: Name of the deployment stage.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)
        if is_after is not None:
            pulumi.set(__self__, "is_after", is_after)
        if is_before is not None:
            pulumi.set(__self__, "is_before", is_before)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the deployment stage.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter(name="isAfter")
    def is_after(self) -> Optional[pulumi.Input[str]]:
        """
        Move the current deployment stage after the target deployment stage
        """
        return pulumi.get(self, "is_after")

    @is_after.setter
    def is_after(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "is_after", value)

    @property
    @pulumi.getter(name="isBefore")
    def is_before(self) -> Optional[pulumi.Input[str]]:
        """
        Move the current deployment stage before the target deployment stage
        """
        return pulumi.get(self, "is_before")

    @is_before.setter
    def is_before(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "is_before", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the deployment stage.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class DeploymentStage(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 is_after: Optional[pulumi.Input[str]] = None,
                 is_before: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## # DeploymentStage (Resource)

        Provides a Qovery deployment stage resource. This can be used to create and manage Qovery deployment stages.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_deployment_stage = qovery.DeploymentStage("myDeploymentStage",
            environment_id=qovery_environment["my_environment"]["id"],
            description="",
            is_after=qovery_deployment_stage["first_deployment_stage"]["id"],
            is_before=qovery_deployment_stage["third_deployment_stage"]["id"],
            opts=pulumi.ResourceOptions(depends_on=[qovery_environment["my_environment"]]))
        ```

        You can find complete examples within these repositories:

        * Deploy services with a specific order

        ## Import

        ```sh
         $ pulumi import qovery:index/deploymentStage:DeploymentStage my_deployment_stage "<environment_id>,<deployment_stage_name>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the deployment stage.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[str] is_after: Move the current deployment stage after the target deployment stage
        :param pulumi.Input[str] is_before: Move the current deployment stage before the target deployment stage
        :param pulumi.Input[str] name: Name of the deployment stage.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeploymentStageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # DeploymentStage (Resource)

        Provides a Qovery deployment stage resource. This can be used to create and manage Qovery deployment stages.

        ## Example

        ```python
        import pulumi
        import ediri_qovery as qovery

        my_deployment_stage = qovery.DeploymentStage("myDeploymentStage",
            environment_id=qovery_environment["my_environment"]["id"],
            description="",
            is_after=qovery_deployment_stage["first_deployment_stage"]["id"],
            is_before=qovery_deployment_stage["third_deployment_stage"]["id"],
            opts=pulumi.ResourceOptions(depends_on=[qovery_environment["my_environment"]]))
        ```

        You can find complete examples within these repositories:

        * Deploy services with a specific order

        ## Import

        ```sh
         $ pulumi import qovery:index/deploymentStage:DeploymentStage my_deployment_stage "<environment_id>,<deployment_stage_name>"
        ```

        :param str resource_name: The name of the resource.
        :param DeploymentStageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeploymentStageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 is_after: Optional[pulumi.Input[str]] = None,
                 is_before: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeploymentStageArgs.__new__(DeploymentStageArgs)

            __props__.__dict__["description"] = description
            if environment_id is None and not opts.urn:
                raise TypeError("Missing required property 'environment_id'")
            __props__.__dict__["environment_id"] = environment_id
            __props__.__dict__["is_after"] = is_after
            __props__.__dict__["is_before"] = is_before
            __props__.__dict__["name"] = name
        super(DeploymentStage, __self__).__init__(
            'qovery:index/deploymentStage:DeploymentStage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            environment_id: Optional[pulumi.Input[str]] = None,
            is_after: Optional[pulumi.Input[str]] = None,
            is_before: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'DeploymentStage':
        """
        Get an existing DeploymentStage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the deployment stage.
        :param pulumi.Input[str] environment_id: Id of the environment.
        :param pulumi.Input[str] is_after: Move the current deployment stage after the target deployment stage
        :param pulumi.Input[str] is_before: Move the current deployment stage before the target deployment stage
        :param pulumi.Input[str] name: Name of the deployment stage.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeploymentStageState.__new__(_DeploymentStageState)

        __props__.__dict__["description"] = description
        __props__.__dict__["environment_id"] = environment_id
        __props__.__dict__["is_after"] = is_after
        __props__.__dict__["is_before"] = is_before
        __props__.__dict__["name"] = name
        return DeploymentStage(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description of the deployment stage.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Output[str]:
        """
        Id of the environment.
        """
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="isAfter")
    def is_after(self) -> pulumi.Output[Optional[str]]:
        """
        Move the current deployment stage after the target deployment stage
        """
        return pulumi.get(self, "is_after")

    @property
    @pulumi.getter(name="isBefore")
    def is_before(self) -> pulumi.Output[Optional[str]]:
        """
        Move the current deployment stage before the target deployment stage
        """
        return pulumi.get(self, "is_before")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the deployment stage.
        """
        return pulumi.get(self, "name")

